# miniminiai

The mini version of fastai's miniai PyTorch framework created during the fastai course 2022-2023.

## Installation

```bash
pip install miniminiai
```

of to install from source clone this repo and run:

```bash
pip install -e .
```

## Usage

Check the notebook [tutorial.ipynb](tutorial.ipynb) for a quick introduction to the framework.